@@ -12,7 +12,7 @@
 #include "incidenceeditor_debug.h"
 
 #include <CalendarSupport/KCalPrefs>
-#include <akonadi/calendar/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
+#include <akonadi/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
 
 #include <KContacts/Addressee>
 
@@ -52,8 +52,8 @@ public:
     bool mCleanupTemporaryFiles;
 
     /// Methods
-    KCalendarCore::Person organizerAsPerson() const;
-    KCalendarCore::Attendee organizerAsAttendee(const KCalendarCore::Person &organizer) const;
+    Q_REQUIRED_RESULT KCalendarCore::Person organizerAsPerson() const;
+    Q_REQUIRED_RESULT KCalendarCore::Attendee organizerAsAttendee(const KCalendarCore::Person &organizer) const;
 
     void todoDefaults(const KCalendarCore::Todo::Ptr &todo) const;
     void eventDefaults(const KCalendarCore::Event::Ptr &event) const;
@@ -78,7 +78,7 @@ KCalendarCore::Person IncidenceDefaultsPrivate::organizerAsPerson() const
     if (!mGroupWareDomain.isEmpty()) {
         // Check if we have an identity with an email that ends with the groupware
         // domain.
-        for (const QString &fullEmail : qAsConst(mEmails)) {
+        for (const QString &fullEmail : std::as_const(mEmails)) {
             QString name;
             QString email;
             const bool success = KEmailAddress::extractEmailAddressAndName(fullEmail, email, name);
@@ -93,7 +93,7 @@ KCalendarCore::Person IncidenceDefaultsPrivate::organizerAsPerson() const
     if (organizer.email() == invalidEmail) {
         // Either, no groupware was used, or we didn't find a groupware email address.
         // Now try to
-        for (const QString &fullEmail : qAsConst(mEmails)) {
+        for (const QString &fullEmail : std::as_const(mEmails)) {
             QString name;
             QString email;
             const bool success = KEmailAddress::extractEmailAddressAndName(fullEmail, email, name);
@@ -135,10 +135,20 @@ void IncidenceDefaultsPrivate::eventDefaults(const KCalendarCore::Event::Ptr &ev
         }
     }
 
+    if (startDT.timeSpec() == Qt::LocalTime) {
+        // Ensure the default is not "floating"
+        startDT.setTimeZone(QTimeZone::systemTimeZone());
+    }
+
     const QTime defaultDurationTime = KCalPrefs::instance()->defaultDuration().time();
     const int defaultDuration = (defaultDurationTime.hour() * 3600) + (defaultDurationTime.minute() * 60);
 
-    const QDateTime endDT = mEndDt.isValid() ? mEndDt : startDT.addSecs(defaultDuration);
+    QDateTime endDT = mEndDt.isValid() ? mEndDt : startDT.addSecs(defaultDuration);
+
+    if (endDT.timeSpec() == Qt::LocalTime) {
+        // Ensure the default is not "floating"
+        endDT.setTimeZone(QTimeZone::systemTimeZone());
+    }
 
     event->setDtStart(startDT);
     event->setDtEnd(endDT);
@@ -215,10 +225,7 @@ IncidenceDefaults::IncidenceDefaults(const IncidenceDefaults &other)
     *d_ptr = *other.d_ptr;
 }
 
-IncidenceDefaults::~IncidenceDefaults()
-{
-    delete d_ptr;
-}
+IncidenceDefaults::~IncidenceDefaults() = default;
 
 IncidenceDefaults &IncidenceDefaults::operator=(const IncidenceDefaults &other)
 {
@@ -293,7 +300,8 @@ void IncidenceDefaults::setAttendees(const QStringList &attendees)
     d->mAttendees.clear();
     QStringList::ConstIterator it;
     for (it = attendees.begin(); it != attendees.end(); ++it) {
-        QString name, email;
+        QString name;
+        QString email;
         KContacts::Addressee::parseEmailAddress(*it, name, email);
         d->mAttendees << KCalendarCore::Attendee(name, email, true, KCalendarCore::Attendee::NeedsAction);
     }
@@ -356,10 +364,10 @@ void IncidenceDefaults::setDefaults(const KCalendarCore::Incidence::Ptr &inciden
     incidence->clearRecurrence();
 
     const KCalendarCore::Person organizerAsPerson = d->organizerAsPerson();
-#ifdef KDEPIM_ENTERPRISE_BUILD
+#if KDEPIM_ENTERPRISE_BUILD
     incidence->addAttendee(d->organizerAsAttendee(organizerAsPerson));
 #endif
-    for (const KCalendarCore::Attendee &attendee : qAsConst(d->mAttendees)) {
+    for (const KCalendarCore::Attendee &attendee : std::as_const(d->mAttendees)) {
         incidence->addAttendee(attendee);
     }
     // Ical standard: No attendees -> must not have an organizer!
@@ -367,7 +375,7 @@ void IncidenceDefaults::setDefaults(const KCalendarCore::Incidence::Ptr &inciden
         incidence->setOrganizer(organizerAsPerson);
     }
 
-    for (const KCalendarCore::Attachment &attachment : qAsConst(d->mAttachments)) {
+    for (const KCalendarCore::Attachment &attachment : std::as_const(d->mAttachments)) {
         incidence->addAttachment(attachment);
     }
 
