@@ -13,10 +13,10 @@
 
 using namespace IncidenceEditorNG;
 
-class Q_DECL_HIDDEN KTimeZoneComboBox::Private
+class IncidenceEditorNG::KTimeZoneComboBoxPrivate
 {
 public:
-    Private(KTimeZoneComboBox *parent)
+    KTimeZoneComboBoxPrivate(KTimeZoneComboBox *parent)
         : mParent(parent)
     {
     }
@@ -26,7 +26,7 @@ public:
     QVector<QByteArray> mZones;
 };
 
-void KTimeZoneComboBox::Private::fillComboBox()
+void KTimeZoneComboBoxPrivate::fillComboBox()
 {
     mParent->clear();
     mZones.clear();
@@ -50,15 +50,12 @@ void KTimeZoneComboBox::Private::fillComboBox()
 
 KTimeZoneComboBox::KTimeZoneComboBox(QWidget *parent)
     : QComboBox(parent)
-    , d(new KTimeZoneComboBox::Private(this))
+    , d(new KTimeZoneComboBoxPrivate(this))
 {
     d->fillComboBox();
 }
 
-KTimeZoneComboBox::~KTimeZoneComboBox()
-{
-    delete d;
-}
+KTimeZoneComboBox::~KTimeZoneComboBox() = default;
 
 void KTimeZoneComboBox::selectTimeZone(const QTimeZone &zone)
 {
@@ -86,6 +83,14 @@ void KTimeZoneComboBox::selectTimeZone(const QTimeZone &zone)
     }
 }
 
+void KTimeZoneComboBox::selectTimeZoneFor(const QDateTime &dateTime)
+{
+    if (dateTime.timeSpec() == Qt::LocalTime)
+        setCurrentIndex(1); // Floating
+    else
+        selectTimeZone(dateTime.timeZone());
+}
+
 QTimeZone KTimeZoneComboBox::selectedTimeZone() const
 {
     QTimeZone zone;
@@ -121,3 +126,17 @@ void KTimeZoneComboBox::setFloating(bool floating, const QTimeZone &zone)
         }
     }
 }
+
+void KTimeZoneComboBox::applyTimeZoneTo(QDateTime &dt) const
+{
+    if (isFloating()) {
+        dt.setTimeSpec(Qt::LocalTime);
+    } else {
+        dt.setTimeZone(selectedTimeZone());
+    }
+}
+
+bool KTimeZoneComboBox::isFloating() const
+{
+    return currentIndex() == 1;
+}
